Balatro
Install with App

Details

Latest version
1.2.0
Last Updated
First Uploaded
Downloads
57
Likes
2
Size
12KB
Dependants

Categories

image

Mod which adds rulers for measuring in-game sizes and distances in Balatro.

Requires Lovely and DebugPlus to work.


rulers command controls the appearance and behaviour of rulers.

rulers [OPTIONS]
  • Multiple options can be passed in command
  • Each option updates only the corresponding property
  • Properties that are not explicitly specified remain unchanged

For example, this command changes only the rulers length.

rulers -l 200px

This command changes the numbers and grid settings while keeping all other properties untouched.

rulers -n off -g on

Options

Help

Display the built-in command reference:

rulers
rulers -h
rulers -help

Visibility

Toggle rulers visibility.

-v BOOLEAN
-visible BOOLEAN
-show
-hide
rulers -show
rulers -v on
rulers -v true
rulers -v t
rulers -v yes
rulers -v y
rulers -v 1
rulers -hide
rulers -v off
rulers -v false
rulers -v no
rulers -v 0
rulers -v any_input_which_is_not_true
Default

Length

Set the rulers length.

-l VALUE
-length VALUE
  • Set length equal to 10 game units
rulers -l 10
  • Set length equal to 200 pixels
rulers -l 200px
  • Reset value to default (3 game units)
rulers -l default
Length

Line size

Set the rulers line size.

-s VALUE
-size VALUE
  • Set size equal to 1 pixel
rulers -s 1
  • Reset value to default (2 pixels)
rulers -s default
Size

Steps

Set the sizes of the three ruler step levels.

-st BIG,MEDIUM,SMALL
-steps BIG,MEDIUM,SMALL
Steps - explanation
  • Set values in game units
rulers -st 2,1,0.25
  • Set values in pixels
rulers -st 50px,25px,5px
  • Reset values to default (Big: 1 game unit; Medium: 0.5 game units; Small: 0.1 game units)
rulers -st default
rulers -st default,default,default
  • Combined
rulers -st 2,default,10px
  • Specify only one value, keeping other ones the same
rulers -st ,,0.125
Steps - pixels

Rotation

Set the clockwise rotation angle.

-r ANGLE
-rotate ANGLE
  • Rotate 30 degrees clockwise
rulers -r 30
rulers -r 30deg
  • Rotate 1 radian clockwise
rulers -r 30
  • Reset value to default (no rotation)
rulers -r default
Rotation

Colour

Set rulers colour. Supplied value is passed to vanilla HEX function.

-c HEX
-colour HEX
  • Set colour to red
rulers -c FF0000
rulers -c #FF0000
  • Reset value to default (00FFFF)
rulers -c default
Colour

Directions

Select which ruler directions should be displayed.
Note than it's relative to not rotated rulers: 90 degree rotated vertical will look like horizontal

Value Direction
v Vertical
h Horizontal
vh Both vertical and horizontal
-d { v | h | vh }
-dir { v | h | vh }
-directions { v | h | vh }
rulers -dir v
rulers -dir h
rulers -dir vh
Directions

Grid

Toggle grid display. Disabled by default.

-g BOOLEAN
-grid BOOLEAN
rulers -g off
rulers -g on
Grid

Numbers

Toggle ruler numbers display. Enabled by default.

-n BOOLEAN
-numbers BOOLEAN
rulers -n off
rulers -n on
Numbers

Pin

rulers -pin to enter pin mode. Then, [Left Mouse] to place a persistent rulers on screen.
[Right Mouse] or repeat command to cancel.

rulers -unpin to unpin pinned rulers.


Reset the entire configuration

Reset all options to their default values.

-reset
-default
rulers -default

Quick reference

rulers [OPTIONS]

Options:
    -h, -help
        Show this message

    -show
        Show rulers

    -hide
        Hide rulers

    -v, -visible BOOLEAN
        Toggle rulers visibility

    -l, -length VALUE
        Set rulers length: n - game units, npx - pixels

    -s, -size VALUE
        Set lines size: n - in pixels

    -st, -steps BIG,MEDIUM,SMALL
        Set line steps: n - game units, npx - pixels

    -r, -rotate ANGLE
        Set rotation angle (clockwise):
        n or ndeg - degrees, nrad - radians

    -c, -colour HEX
        Set colour (input passed to HEX function)

    -d, -dir, -directions v | h | vh
        Set directions to display:
        v - vertical, h - horizontal, vh - both

    -g, -grid BOOLEAN
        Toggle grid

    -n, -numbers BOOLEAN
        Toggle numbers display

    -reset, -default
        Reset all options to their default values

    -pin
        Enable pin mode: [Left Mouse] to place persistent rulers on screen
        [Right Mouse] or repeat command to cancel

    -unpin
        Unpin pinned rulers
Thunderstore development is made possible with ads. Please consider making an exception to your adblock.